==> openapi_jira_client-0.0.1-py3-none-any.whl: openapi_jira_client/models/custom_field_definition_json_bean.py <==
from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.componentsschemas_custom_field_definition_json_bean_searcher_key import (
    ComponentsschemasCustomFieldDefinitionJsonBeanSearcherKey,
)
from ..models.componentsschemas_custom_field_definition_json_bean_type import (
    ComponentsschemasCustomFieldDefinitionJsonBeanType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="CustomFieldDefinitionJsonBean")


@attr.s(auto_attribs=True)
class CustomFieldDefinitionJsonBean:
    """  """

    name: str
    type_: ComponentsschemasCustomFieldDefinitionJsonBeanType
    description: Union[Unset, str] = UNSET
    searcher_key: Union[Unset, ComponentsschemasCustomFieldDefinitionJsonBeanSearcherKey] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        type_ = self.type_.value

        description = self.description
        searcher_key: Union[Unset, str] = UNSET
        if not isinstance(self.searcher_key, Unset):
            searcher_key = self.searcher_key.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "name": name,
                "type": type_,
            }
        )
        if description is not UNSET:
            field_dict["description"] = description
        if searcher_key is not UNSET:
            field_dict["searcherKey"] = searcher_key

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        type_ = ComponentsschemasCustomFieldDefinitionJsonBeanType(d.pop("type"))

        description = d.pop("description", UNSET)

        searcher_key: Union[Unset, ComponentsschemasCustomFieldDefinitionJsonBeanSearcherKey] = UNSET
        _searcher_key = d.pop("searcherKey", UNSET)
        if not isinstance(_searcher_key, Unset):
            searcher_key = ComponentsschemasCustomFieldDefinitionJsonBeanSearcherKey(_searcher_key)

        custom_field_definition_json_bean = cls(
            name=name,
            type_=type_,
            description=description,
            searcher_key=searcher_key,
        )

        return custom_field_definition_json_bean

==> openapi_jira_client-3.0.0-py3-none-any.whl: openapi_jira_client/models/custom_field_definition_json_bean.py <==
from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.custom_field_definition_json_bean_searcher_key import CustomFieldDefinitionJsonBeanSearcherKey
from ..models.custom_field_definition_json_bean_type import CustomFieldDefinitionJsonBeanType
from ..types import UNSET, Unset

T = TypeVar("T", bound="CustomFieldDefinitionJsonBean")


@attr.s(auto_attribs=True)
class CustomFieldDefinitionJsonBean:
    """  """

    name: str
    type: CustomFieldDefinitionJsonBeanType
    searcher_key: CustomFieldDefinitionJsonBeanSearcherKey
    description: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        type = self.type.value

        searcher_key = self.searcher_key.value

        description = self.description

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "name": name,
                "type": type,
                "searcherKey": searcher_key,
            }
        )
        if description is not UNSET:
            field_dict["description"] = description

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        type = CustomFieldDefinitionJsonBeanType(d.pop("type"))

        searcher_key = CustomFieldDefinitionJsonBeanSearcherKey(d.pop("searcherKey"))

        description = d.pop("description", UNSET)

        custom_field_definition_json_bean = cls(
            name=name,
            type=type,
            searcher_key=searcher_key,
            description=description,
        )

        return custom_field_definition_json_bean
